@@ -9,7 +9,7 @@ int main(int argc, char *argv[]) {
 	int uid = getuid();
 	if (uid != 0) {
 		cout << "You are not root. Correcting that." << endl;
-		execlp("kdesu", "kdesu", "./trunk", NULL);
+		execlp("kdesu", "kdesu", "accel-manager", NULL);
 	} 
 	QApplication app(argc, argv);
 	AccelManagerGUI manager;
